==> firefox-61.0b6.source.tar.xz: firefox-61.0/browser/extensions/activity-stream/prerendered/locales/si/activity-stream-strings.js <==
// Note - this is a generated si file.
window.gActivityStreamStrings = {
  "newtab_page_title": "නව ටැබය",
  "header_top_sites": "ප්‍රමුඛ අඩවි",
  "header_highlights": "ඉස්මතු කිරීම්",
  "header_recommended_by": "{provider} විසින් නිර්දේශිතයි",
  "context_menu_button_sr": "Open context menu for {title}",
  "section_context_menu_button_sr": "Open the section context menu",
  "type_label_visited": "ප්‍රවේශිත",
  "type_label_bookmarked": "පිටු සලකුණු තැබූ",
  "type_label_recommended": "Trending",
  "type_label_pocket": "Saved to Pocket",
  "type_label_downloaded": "Downloaded",
  "menu_action_bookmark": "පිටු සලකුණ",
  "menu_action_remove_bookmark": "පිටු සලකුණ ඉවත් කරන්න",
  "menu_action_open_new_window": "නව කවුළුවක විවෘත කරන්න",
  "menu_action_open_private_window": "නව පුද්ගලික කවුළුවක විවෘත කරන්න",
  "menu_action_dismiss": "ඉවත් කරන්න",
  "menu_action_delete": "අතිතයෙන් මකන්න කරන්න",
  "menu_action_pin": "ඇමිණීම",
  "menu_action_unpin": "ඇමුණුම ඉවත් කරන්න",
  "confirm_history_delete_p1": "ඔබට මෙම පිටුවට අදාල සියලුම සිදුවීම් ඔබේ අතීතයන් මැකීමට අවශ්‍ය ද?",
  "confirm_history_delete_notice_p2": "මෙම ක්‍රියාව අහෝසි කළ නොහැක.",
  "menu_action_save_to_pocket": "Save to Pocket",
  "menu_action_delete_pocket": "Delete from Pocket",
  "menu_action_archive_pocket": "Archive in Pocket",
  "menu_action_show_file_mac_os": "Show in Finder",
  "menu_action_show_file_windows": "Open Containing Folder",
  "menu_action_show_file_linux": "Open Containing Folder",
  "menu_action_show_file_default": "Show File",
  "menu_action_open_file": "Open File",
  "menu_action_copy_download_link": "Copy Download Link",
  "menu_action_go_to_download_page": "Go to Download Page",
  "menu_action_remove_download": "Remove from History",
  "search_button": "සොයන්න",
  "search_header": "{search_engine_name} ෙසවුම",
  "search_web_placeholder": "ජාලය තුළ සොයන්න",
  "section_disclaimer_topstories": "The most interesting stories on the web, selected based on what you read. From Pocket, now part of Mozilla.",
  "section_disclaimer_topstories_linktext": "එය ක්‍රියාකරන්නේ කෙසේදැයි අධ්‍යපනය කරන්න.",
  "section_disclaimer_topstories_buttontext": "හරි, තේරුණා",
  "prefs_home_header": "Firefox Home Content",
  "prefs_home_description": "Choose what content you want on your Firefox Home screen.",
  "prefs_section_rows_option": "{num} row;{num} rows",
  "prefs_search_header": "Web Search",
  "prefs_topsites_description": "The sites you visit most",
  "prefs_topstories_description2": "Great content from around the web, personalized for you",
  "prefs_topstories_options_sponsored_label": "Sponsored Stories",
  "prefs_topstories_sponsored_learn_more": "Learn more",
  "prefs_highlights_description": "A selection of sites that you’ve saved or visited",
  "prefs_highlights_options_visited_label": "Visited Pages",
  "prefs_highlights_options_download_label": "Most Recent Download",
  "prefs_highlights_options_pocket_label": "Pages Saved to Pocket",
  "prefs_snippets_description": "Updates from Mozilla and Firefox",
  "settings_pane_button_label": "ඔබේ නව ටැබ පිටුව රුචිකරණය කරන්න",
  "settings_pane_topsites_header": "ප්‍රමුඛ අඩවි",
  "settings_pane_highlights_header": "ඉස්මතු කිරීම්",
  "settings_pane_highlights_options_bookmarks": "පිටු සලකුණු",
  "settings_pane_snippets_header": "Snippets",
  "edit_topsites_button_text": "සැකසුම්",
  "edit_topsites_edit_button": "මෙම අඩවිය සකසන්න",
  "topsites_form_add_header": "නව ප්‍රමුඛ අඩවියක්",
  "topsites_form_edit_header": "ප්‍රමුඛ අඩවිය සකසන්න",
  "topsites_form_title_label": "Title",
  "topsites_form_title_placeholder": "සිරස්තල එක් කරන්න",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "Custom Image URL",
  "topsites_form_url_placeholder": "URL එකක් ඇතුළත් කරන්න",
  "topsites_form_use_image_link": "Use a custom image…",
  "topsites_form_preview_button": "Preview",
  "topsites_form_add_button": "එක් කරන්න",
  "topsites_form_save_button": "සුරකින්න",
  "topsites_form_cancel_button": "අවලංගු කරන්න",
  "topsites_form_url_validation": "වලංගු URL එකක් අවශ්‍ය වේ",
  "topsites_form_image_validation": "Image failed to load. Try a different URL.",
  "pocket_read_more": "ජනප්‍රිය මාතෘකා:",
  "pocket_read_even_more": "තවත් බොහෝ දැ",
  "highlights_empty_state": "Start browsing, and we’ll show some of the great articles, videos, and other pages you’ve recently visited or bookmarked here.",
  "topstories_empty_state": "You’ve caught up. Check back later for more top stories from {provider}. Can’t wait? Select a popular topic to find more great stories from around the web.",
  "manual_migration_explanation2": "Firefox වෙනත් ගවේශයකය පිටය සලකුණු, අතීතය සහ මුරපද සමග උත්සාහ කර බලන්න.",
  "manual_migration_cancel_button": "එපා, ස්තුතියි",
  "manual_migration_import_button": "දැන් ආයාත කරන්න",
  "error_fallback_default_info": "Oops, something went wrong loading this content.",
  "error_fallback_default_refresh_suggestion": "Refresh page to try again.",
  "section_menu_action_remove_section": "Remove Section",
  "section_menu_action_collapse_section": "Collapse Section",
  "section_menu_action_expand_section": "Expand Section",
  "section_menu_action_manage_section": "Manage Section",
  "section_menu_action_add_topsite": "Add Top Site",
  "section_menu_action_move_up": "Move Up",
  "section_menu_action_move_down": "Move Down",
  "section_menu_action_privacy_notice": "Privacy Notice",
  "default_label_loading": "පූරණය වෙමින්…",
  "header_stories": "ප්‍රමුඛ පුවත්",
  "header_visit_again": "යළි පිවිසෙන්න",
  "header_bookmarks": "නැවුම් පිටු සලකුණු",
  "header_bookmarks_placeholder": "ඔබ සතුව තවම පිටුසලකුණු නැත.",
  "header_stories_from": "සිට​",
  "type_label_synced": "වෙනත් උපාංගයක් වෙතින් සමකාලීන​ කර ඇත​",
  "type_label_open": "විවෘත",
  "type_label_topic": "මාතෘකාව",
  "type_label_now": "දැන්",
  "menu_action_copy_address": "ලිපිනය පිටපත් කරන්න",
  "menu_action_email_link": "විද්‍යුත් තැපැල් සබැඳි…",
  "search_for_something_with": "{search_term} සදහා සෙවීමට භාවිත කළ යුත්තේ:",
  "search_settings": "සෙවුම් සැකසුම් වෙනස් කරන්න",
  "section_info_option": "තොරතුරු",
  "section_info_send_feedback": "ප්‍රතිචාරය යවන්න",
  "section_info_privacy_notice": "පෞද්ගලිකත්ව දැනුම්දීම්",
  "welcome_title": "නව ටැබයට සාදරයෙන් පිළිගනිමු",
  "welcome_body": "ඔබට පහසුවෙන් යළි භාවිතයට පහසු කරවීමට, Firefox මෙම ඉඩ ඔබට වඩාත් අදාල පිටු සළකුණු, ලිපි, විඩියෝ සහ ඔබ මෑතකදී පිවිසි පිටු පෙන්වීම සදහා භාවිත කරයි.",
  "welcome_label": "ඔබේ ඉස්මතු කිරීම් හදුනාගනිමින්",
  "time_label_less_than_minute": "<1m",
  "time_label_minute": "{number} මිනිත්තු",
  "time_label_hour": "{number}පැය",
  "time_label_day": "{number}දින",
  "settings_pane_header": "නව ටැබ අභිප්‍රේත",
  "settings_pane_body2": "මෙම පිටුවේ ඔබ දැකිය යුතු දේ තෝරන්න.",
  "settings_pane_search_header": "සොයන්න",
  "settings_pane_search_body": "ඔබේ නව ටැබයෙන් වෙබ් සෙවීම.",
  "settings_pane_topsites_body": "ඔබ නිරතුරුව පිවිසෙන වෙබ් අඩවි වෙත ප්‍රවේශය.",
  "settings_pane_topsites_options_showmore": "පේළි දෙකක් පෙන්වන්න",
  "settings_pane_bookmarks_header": "නැවුම් පිටු සලකුණු",
  "settings_pane_bookmarks_body": "ඔබේ නැවුම් පිටු සලකුණු එක් ස්ථානයක.",
  "settings_pane_visit_again_header": "යළි පිවිසෙන්න",
  "settings_pane_highlights_options_visited": "පිවිසුණු අඩවි",
  "settings_pane_topstories_options_sponsored": "අනුග්‍රහක පුවත් පෙන්වන්න",
  "edit_topsites_showmore_button": "තවත් පෙන්වන්න",
  "edit_topsites_showless_button": "අඩුවෙන් පෙන්වන්න",
  "edit_topsites_done_button": "කළා",
  "edit_topsites_dismiss_button": "මෙම අඩවිය ඉවත ලන්න",
  "edit_topsites_add_button": "එක් කරන්න"
};

==> firefox-62.0b14.source.tar.xz: firefox-62.0/browser/extensions/activity-stream/prerendered/locales/si/activity-stream-strings.js <==
// Note - this is a generated si file.
window.gActivityStreamStrings = {
  "newtab_page_title": "නව ටැබය",
  "header_top_sites": "ප්‍රමුඛ අඩවි",
  "header_highlights": "ඉස්මතු කිරීම්",
  "header_recommended_by": "{provider} විසින් නිර්දේශිතයි",
  "context_menu_button_sr": "Open context menu for {title}",
  "section_context_menu_button_sr": "Open the section context menu",
  "type_label_visited": "ප්‍රවේශිත",
  "type_label_bookmarked": "පිටු සලකුණු තැබූ",
  "type_label_recommended": "Trending",
  "type_label_pocket": "Saved to Pocket",
  "type_label_downloaded": "Downloaded",
  "menu_action_bookmark": "පිටු සලකුණ",
  "menu_action_remove_bookmark": "පිටු සලකුණ ඉවත් කරන්න",
  "menu_action_open_new_window": "නව කවුළුවක විවෘත කරන්න",
  "menu_action_open_private_window": "නව පුද්ගලික කවුළුවක විවෘත කරන්න",
  "menu_action_dismiss": "ඉවත් කරන්න",
  "menu_action_delete": "අතිතයෙන් මකන්න කරන්න",
  "menu_action_pin": "ඇමිණීම",
  "menu_action_unpin": "ඇමුණුම ඉවත් කරන්න",
  "confirm_history_delete_p1": "ඔබට මෙම පිටුවට අදාල සියලුම සිදුවීම් ඔබේ අතීතයන් මැකීමට අවශ්‍ය ද?",
  "confirm_history_delete_notice_p2": "මෙම ක්‍රියාව අහෝසි කළ නොහැක.",
  "menu_action_save_to_pocket": "Save to Pocket",
  "menu_action_delete_pocket": "Delete from Pocket",
  "menu_action_archive_pocket": "Archive in Pocket",
  "menu_action_show_file_mac_os": "Show in Finder",
  "menu_action_show_file_windows": "Open Containing Folder",
  "menu_action_show_file_linux": "Open Containing Folder",
  "menu_action_show_file_default": "Show File",
  "menu_action_open_file": "Open File",
  "menu_action_copy_download_link": "Copy Download Link",
  "menu_action_go_to_download_page": "Go to Download Page",
  "menu_action_remove_download": "Remove from History",
  "search_button": "සොයන්න",
  "search_header": "{search_engine_name} ෙසවුම",
  "search_web_placeholder": "ජාලය තුළ සොයන්න",
  "section_disclaimer_topstories": "The most interesting stories on the web, selected based on what you read. From Pocket, now part of Mozilla.",
  "section_disclaimer_topstories_linktext": "එය ක්‍රියාකරන්නේ කෙසේදැයි අධ්‍යපනය කරන්න.",
  "section_disclaimer_topstories_buttontext": "හරි, තේරුණා",
  "prefs_home_header": "Firefox Home Content",
  "prefs_home_description": "Choose what content you want on your Firefox Home screen.",
  "prefs_section_rows_option": "{num} row;{num} rows",
  "prefs_search_header": "Web Search",
  "prefs_topsites_description": "The sites you visit most",
  "prefs_topstories_description2": "Great content from around the web, personalized for you",
  "prefs_topstories_options_sponsored_label": "Sponsored Stories",
  "prefs_topstories_sponsored_learn_more": "Learn more",
  "prefs_highlights_description": "A selection of sites that you’ve saved or visited",
  "prefs_highlights_options_visited_label": "Visited Pages",
  "prefs_highlights_options_download_label": "Most Recent Download",
  "prefs_highlights_options_pocket_label": "Pages Saved to Pocket",
  "prefs_snippets_description": "Updates from Mozilla and Firefox",
  "settings_pane_button_label": "ඔබේ නව ටැබ පිටුව රුචිකරණය කරන්න",
  "settings_pane_topsites_header": "ප්‍රමුඛ අඩවි",
  "settings_pane_highlights_header": "ඉස්මතු කිරීම්",
  "settings_pane_highlights_options_bookmarks": "පිටු සලකුණු",
  "settings_pane_snippets_header": "Snippets",
  "edit_topsites_button_text": "සැකසුම්",
  "edit_topsites_edit_button": "මෙම අඩවිය සකසන්න",
  "topsites_form_add_header": "නව ප්‍රමුඛ අඩවියක්",
  "topsites_form_edit_header": "ප්‍රමුඛ අඩවිය සකසන්න",
  "topsites_form_title_label": "Title",
  "topsites_form_title_placeholder": "සිරස්තල එක් කරන්න",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "Custom Image URL",
  "topsites_form_url_placeholder": "URL එකක් ඇතුළත් කරන්න",
  "topsites_form_use_image_link": "Use a custom image…",
  "topsites_form_preview_button": "Preview",
  "topsites_form_add_button": "එක් කරන්න",
  "topsites_form_save_button": "සුරකින්න",
  "topsites_form_cancel_button": "අවලංගු කරන්න",
  "topsites_form_url_validation": "වලංගු URL එකක් අවශ්‍ය වේ",
  "topsites_form_image_validation": "Image failed to load. Try a different URL.",
  "pocket_read_more": "ජනප්‍රිය මාතෘකා:",
  "pocket_read_even_more": "තවත් බොහෝ දැ",
  "highlights_empty_state": "Start browsing, and we’ll show some of the great articles, videos, and other pages you’ve recently visited or bookmarked here.",
  "topstories_empty_state": "You’ve caught up. Check back later for more top stories from {provider}. Can’t wait? Select a popular topic to find more great stories from around the web.",
  "manual_migration_explanation2": "Firefox වෙනත් ගවේශයකය පිටය සලකුණු, අතීතය සහ මුරපද සමග උත්සාහ කර බලන්න.",
  "manual_migration_cancel_button": "එපා, ස්තුතියි",
  "manual_migration_import_button": "දැන් ආයාත කරන්න",
  "error_fallback_default_info": "Oops, something went wrong loading this content.",
  "error_fallback_default_refresh_suggestion": "Refresh page to try again.",
  "section_menu_action_remove_section": "Remove Section",
  "section_menu_action_collapse_section": "Collapse Section",
  "section_menu_action_expand_section": "Expand Section",
  "section_menu_action_manage_section": "Manage Section",
  "section_menu_action_manage_webext": "Manage Extension",
  "section_menu_action_add_topsite": "Add Top Site",
  "section_menu_action_move_up": "Move Up",
  "section_menu_action_move_down": "Move Down",
  "section_menu_action_privacy_notice": "Privacy Notice",
  "firstrun_title": "Take Firefox with You",
  "firstrun_content": "Get your bookmarks, history, passwords and other settings on all your devices.",
  "firstrun_learn_more_link": "Learn more about Firefox Accounts",
  "firstrun_form_header": "Enter your email",
  "firstrun_form_sub_header": "to continue to Firefox Sync",
  "firstrun_email_input_placeholder": "Email",
  "firstrun_extra_legal_links": "By proceeding, you agree to the {terms} and {privacy}.",
  "firstrun_terms_of_service": "Terms of Service",
  "firstrun_privacy_notice": "Privacy Notice",
  "firstrun_continue_to_login": "Continue",
  "firstrun_skip_login": "Skip this step",
  "default_label_loading": "පූරණය වෙමින්…",
  "header_stories": "ප්‍රමුඛ පුවත්",
  "header_visit_again": "යළි පිවිසෙන්න",
  "header_bookmarks": "නැවුම් පිටු සලකුණු",
  "header_bookmarks_placeholder": "ඔබ සතුව තවම පිටුසලකුණු නැත.",
  "header_stories_from": "සිට​",
  "type_label_synced": "වෙනත් උපාංගයක් වෙතින් සමකාලීන​ කර ඇත​",
  "type_label_open": "විවෘත",
  "type_label_topic": "මාතෘකාව",
  "type_label_now": "දැන්",
  "menu_action_copy_address": "ලිපිනය පිටපත් කරන්න",
  "menu_action_email_link": "විද්‍යුත් තැපැල් සබැඳි…",
  "search_for_something_with": "{search_term} සදහා සෙවීමට භාවිත කළ යුත්තේ:",
  "search_settings": "සෙවුම් සැකසුම් වෙනස් කරන්න",
  "section_info_option": "තොරතුරු",
  "section_info_send_feedback": "ප්‍රතිචාරය යවන්න",
  "section_info_privacy_notice": "පෞද්ගලිකත්ව දැනුම්දීම්",
  "welcome_title": "නව ටැබයට සාදරයෙන් පිළිගනිමු",
  "welcome_body": "ඔබට පහසුවෙන් යළි භාවිතයට පහසු කරවීමට, Firefox මෙම ඉඩ ඔබට වඩාත් අදාල පිටු සළකුණු, ලිපි, විඩියෝ සහ ඔබ මෑතකදී පිවිසි පිටු පෙන්වීම සදහා භාවිත කරයි.",
  "welcome_label": "ඔබේ ඉස්මතු කිරීම් හදුනාගනිමින්",
  "time_label_less_than_minute": "<1m",
  "time_label_minute": "{number} මිනිත්තු",
  "time_label_hour": "{number}පැය",
  "time_label_day": "{number}දින",
  "settings_pane_header": "නව ටැබ අභිප්‍රේත",
  "settings_pane_body2": "මෙම පිටුවේ ඔබ දැකිය යුතු දේ තෝරන්න.",
  "settings_pane_search_header": "සොයන්න",
  "settings_pane_search_body": "ඔබේ නව ටැබයෙන් වෙබ් සෙවීම.",
  "settings_pane_topsites_body": "ඔබ නිරතුරුව පිවිසෙන වෙබ් අඩවි වෙත ප්‍රවේශය.",
  "settings_pane_topsites_options_showmore": "පේළි දෙකක් පෙන්වන්න",
  "settings_pane_bookmarks_header": "නැවුම් පිටු සලකුණු",
  "settings_pane_bookmarks_body": "ඔබේ නැවුම් පිටු සලකුණු එක් ස්ථානයක.",
  "settings_pane_visit_again_header": "යළි පිවිසෙන්න",
  "settings_pane_highlights_options_visited": "පිවිසුණු අඩවි",
  "settings_pane_topstories_options_sponsored": "අනුග්‍රහක පුවත් පෙන්වන්න",
  "edit_topsites_showmore_button": "තවත් පෙන්වන්න",
  "edit_topsites_showless_button": "අඩුවෙන් පෙන්වන්න",
  "edit_topsites_done_button": "කළා",
  "edit_topsites_dismiss_button": "මෙම අඩවිය ඉවත ලන්න",
  "edit_topsites_add_button": "එක් කරන්න"
};
